@@ -36,7 +36,8 @@ import Data.Text.Encoding (encodeUtf8, decodeUtf8)
 import Blaze.ByteString.Builder (toByteString)
 import Network.HTTP.Types (renderQueryText)
 import Control.Exception (throwIO)
-import Data.Conduit (MonadBaseControl, MonadResource)
+import Control.Monad.Trans.Control (MonadBaseControl)
+import Control.Monad.Trans.Resource (MonadResource)
 
 getForwardUrl
     :: (MonadResource m, MonadBaseControl IO m)
@@ -48,7 +49,7 @@ getForwardUrl
     -> m Text -- ^ URL to send the user to.
 getForwardUrl openid' complete mrealm params manager = do
     let realm = fromMaybe complete mrealm
-    claimed <- normalize openid'
+    claimed <- normalize $ T.strip openid'
     disc <- discover claimed manager
     let helper s q = return $ T.concat
             [ s
